@@ -11,6 +11,7 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from six.moves import urllib
 
 from muranoclient.common import base
 
@@ -31,21 +32,26 @@ class Status(base.Resource):
         return self.manager.data(self, **kwargs)
 
 
-class EnvironmentManager(base.Manager):
+class EnvironmentManager(base.ManagerWithFind):
     resource_class = Environment
 
-    def list(self):
-        return self._list('/v1/environments', 'environments')
+    def list(self, all_tenants=False):
+        path = '/v1/environments?{query}'.format(
+            query=urllib.parse.urlencode({'all_tenants': all_tenants}))
+        return self._list(path, 'environments')
 
-    def create(self, body):
-        return self._create('/v1/environments', body)
+    def create(self, data):
+        return self._create('/v1/environments', data)
 
     def update(self, environment_id, name):
         return self._update('/v1/environments/{id}'.format(id=environment_id),
-                            body={'name': name})
+                            data={'name': name})
 
-    def delete(self, environment_id):
-        return self._delete('/v1/environments/{id}'.format(id=environment_id))
+    def delete(self, environment_id, abandon=False):
+        path = '/v1/environments/{id}?{query}'.format(
+            id=environment_id,
+            query=urllib.parse.urlencode({'abandon': abandon}))
+        return self._delete(path)
 
     def get(self, environment_id, session_id=None):
         if session_id:
